/* 
Workflow Template using Stata, MarkDoc, and LaTeX
*** NO MACROS (for template with macros, see alternative template) ***
Authors: Matthew C. Ingram, Nakissa Jahanbani, and Cesar Renteria
Rockefeller College of Public Affairs and Policy
University at Albany, SUNY
General Template - Stata using MarkDoc package with LaTeX
Use for written assignments in RPAD/RPOS 517 (using Stata)
Date created: 20170122
Last updated: 20170906
Sources:
Adapted from examples by E.F. Haghish here: 
http://www.haghish.com/statistics/stata-blog/reproducible-research/markdoc.php
*/

//-------------------------------

/* ----------------------- 
Environment Setup
--------------------------
*/

log close _all
clear all // this clears data, analysis previously loaded
set more off // this allows all results to print at once, rather than one screen at a time
set linesize 70 // this controls width of text lines in Stata; 
				// avoid wrapping or running off page
version 13  // sets Stata version; 
			// if necessary, use more recent version (Stata 15 released June 2017)

/* ------------------------
set working directory
---------------------------
Note: this is the filepath to one of our directories on a Windows PC; change to your own
for Mac OS, change forward slashes (\) to backslashes (/)
*/

* option 1: set directly
cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata"
* cd "/Users/nakissajahanbani/Dropbox/Workflow [Ingram]/Template-Latex"

* check directory contents
dir

* if subfolders missing, create them
// add new subfolders within this directory for figures and other output

capture mkdir data
capture mkdir figures
capture mkdir output
capture mkdir tables

// check to make sure subdirectories created:
dir

/*
* alternative option: use macros to set file paths
global path "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata"
* global path "/Users/nakissajahanbani/Dropbox/Workflow [Ingram]/Template-Latex"

* can also do this for subfolders
global pathdata "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\data"
global pathfig "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\figures"
global pathout "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\output"
global pathtab "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\tables"
cd $path
*/

/* ------------------------
create research log
---------------------------
*/

* open research log / all your output goes here 
quietly log using mytemplatelatexnomacros, replace

* ----------------------------
* load/install packages
* ----------------------------

/* 
If needed, install necessary packages to compile notebook document (e.g., html, docx, pdf)
these packages include: markdoc, kethcup, weaver, synlight, and statax
note: if get any error messages, follow on-screen instructions in Stata console to 
complete correct installation

* once install following packages once, do not need to re-install; 
* here, commented out
*/
* packages for MarkDoc
* ssc install Markdoc
* ssc install weaver
* ssc install synlight
* ssc install statax
* markdocpandoc // installs pandoc
* packages for analysis and presentation of results
* ssc install estout, replace
* ssc install outreg
* ssc install pandoc
* ssc install coefplot 

*-----------------------
*-----------------------


/* Template: 
MI 20170122: 
comments from Stata do-file will not appear in final markdoc.
The text included in this do-file will only appear if it
is blocked between a forward slash '/' and 3 asterisks '***', as done below
immediately before start of latex syntax.
*/
	

/***

\documentclass{article}

\usepackage{graphicx}  % this is a package for inserting graphics
\usepackage{hyperref}
\hypersetup{
    colorlinks=true,
    linkcolor=blue,
    filecolor=blue,      
    urlcolor=blue
	}
	
\usepackage{geometry}	% useful package for formatting document
\geometry{
	letterpaper,
	total={6.5in, 9in},
	left=1in,
	right=1in,
	top=1in,
	bottom=1in
	}

\begin{document}

\title{Template using MarkDoc and \LaTeX{} within Stata .do File}
\author{
  Matthew C. Ingram$^1$
  \and
  Nakissa Jahanbani$^1$
  \and
  C\'{e}sar Renter\'{i}a$^2$
  }

 \date{
  $^1$ Department of Political Science\\
  $^2$ Department of Public Affairs \& Policy\\ 
  \\
  Rockefeller College of Public Affairs \& Policy\\
  \bigskip
  \today
  }

\maketitle
	
\begin{abstract}
\textbf{Summary}. Type your summary or abstract here, if desired. If there is 
none or if this part is not relevant, then omit.
\end{abstract}

\section{Purpose of this document}

This document offers you a template to improve your workflow in Stata 
using \LaTeX and the MarkDoc package.

\section{Template in greater detail}

This is the template for all assignments you produce for RPAD/RPOS 517. 
Please use this template for each assignment, and please submit all 
assignments as PDF documents.

There are three versions of the template: 

\begin{itemize}
  \item[1] one for Stata using MarkDoc and \LaTeX (.do file)
  \item[2] one for R using Sweave and \LaTeX (.Rnw) 
  \item[3] one for R using knitr and markdown (.Rmd file)
\end{itemize}

This template is the first one: Stata with MarkDoc and \LaTeX.

Each template offers a combination of three main tools, including a statistical package (Stata or R), a text processing and presentation 
system or language (\LaTeX, markdown, and/or HTML), and a system for weaving together code from the statistical package and the text and formatting 
from the text processing and presentation system (MarkDoc, Sweave, or knitr).

What you choose will likely depend on your needs, and this may vary from one project to another.
For instance, HTML may be a better choice for producing web pages and other web content, and 
markdown may be a better choice for producing short reports with little formatting.
It may also be the case that one collaboration you have uses one set of tools and another team you work with 
uses a different set of tools.

In general, however, I recommend learning and using \LaTeX; this is a powerful 
document preparation and typesetting system that will meet all of your needs.

\section{Getting started}

At this point, I assume the following:

\begin{itemize}

  \item[\circ]  you have access to Stata
  
	\begin{itemize}
		\item	for student and educational pricing, see \href{https://www.stata.com/order/new/edu/gradplans/student-pricing/}{here}
		\item 	I do not recommend Small Stata; you will quickly run into limitations
	\end{itemize}
  \item[\circ]  you have downloaded and installed a .tex distribution and 
  .tex editor 
  see \href{http://mattingram.net/Teaching/QuantitativeMethods/latexnotes.pdf}{Notes on \LaTeX})
\end{itemize}

If all of the above is correct, open Stata.\\

This .do file using MarkDoc and \LaTeX can then be easily opened and edited 
in Stata.\\

MarkDoc enhances your workflow in Stata by allowing you 
to integrate your Stata syntax with document preparation and typesetting tools 
to control the appearance of your content. Specifically, MarkDoc is designed to 
use three tools (markdown, HTML, and \LaTeX).

For more on MarkDoc, see package documentation 
\href{http://www.haghish.com/statistics/stata-blog/reproducible-research/markdoc.php}{here}.

Once you have opened this .do file in Stata, you can run this .do file by:
\begin{itemize}
	\item[(a)] placing your cursor at start of document and clicking the ``Execute (do)'' button at top-right above; 
	\item[(b)] highlighting the parts you want to run and hitting CTRL-D (CMD-D on Mac), or 
	\item[(c)] run the whole file by simply hitting CTRL-D (CMD-D on Mac).
\end{itemize}

MarkDoc converts your smcl logfile (.smcl) to a \LaTeX  file (.tex), 
which you will then need to compile. \\
For compiling your .tex file and any related figures, tables, 
or other output, you will need a .tex distribution and a .tex editor.  
There are several distribution and editors available, but I recommend the MiKTeX 
distribution and TeXstudio editor for Windows, and the MacTeX distribution and 
TeXshop editor for Mac. Running your .do-file in Stata will generate a .tex 
file, and you will then open and compile this file in your .tex editor 
(e.g., TeXstudio), which will output a finished .pdf document (though 
other formats are available). To read a basic introduction to \LaTeX, including 
suggestions for .tex editors, see 
\href{http://mattingram.net/Teaching/QuantitativeMethods/latexnotes.pdf}{Notes on \LaTeX}.

When you run this do-file, a .tex file will be generated that includes both 
text content as well as any embedded Stata code and the output of any Stata 
code blocks within the document. You can embed a chunk of Stata code by 
placing it outside the forward slash and three asterisks and three asterisks 
and a forward slash as illustrated below with the ``verbatim'' command from 
\LaTeX.\\


\section{Quick intro to \LaTeX}

A few useful \LaTeX commands for writing are: \\

\section{This is heading 1}

\section*{This is a heading 1 without numbering}

\subsection{This is heading 2}

\subsection*{This is heading 2 without numbering}

This is a text paragraph which requires no syntax.\\

This is a list of items:
\begin{itemize}
	\item[\bullet] item 1
	\item[\circ] item 2
\end{itemize}

\noindent This is a line introducing Equation 1 and Equation 2 below.

\begin{equation}
\label{simple_equation}
\alpha = \sqrt{ \beta }
\end{equation}
	
\begin{equation}
\label{Bivariate OLS}
y = {\beta_0 + \beta_1X_1 + \beta_2X_2 + \epsilon}
\end{equation}


In the blocks of Stata code below, we illustrate several typical steps in the 
course of writing a paper, including:

\begin{itemize}
	\item[1] loading some data, 
	\item[2] describing the data, including a table of summary statistics,
	\item[3] graphing the data,
	\item[4] running a simple regression model, 
	\item[5] graphing the results.
\end{itemize}

\section{Data Analysis Example}

This document provides an example about how to use MarkDoc to add \LaTex text to 
your logfile. To do so, I will use the winter olympics dataset for Michael 
Bailey's statistics text, Real Stats (Oxford, 2016).\\

Data are in a folder called ``data'', and all figures are exported to and then imported from a folder called ``figures''.

\section{Loading Data}

In this section, we load our data. \\

All Stata commands have been suppresed with 
`/**/' syntax at start of each line of code.\\

All unwanted results have also been suppressed by using the command `quietly'.\\

\begin{verbatim}
***/

/* ------------------------
load dataset
---------------------------
*/

* get data from web:
/**/ quietly import delimited using "http://mattingram.net/Teaching/workflow/olympics_HW.csv"
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\data"
/**/ quietly save olympics, replace

*cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\data"
* quietly use olympics.dta

*import delimited using olympics.csv

/* 
other options:
* csv in current directory
import delimited using olympics_HW.csv
* with macros
quietly cd $pathdata
* load .dta file from current directory
quietly use olympics.dta
* if get error regarding version, try file olympics_v13.dta

* or simply: use ./data/olympics.dta
* be thoughtful about labels and variable names
* can add labels with: label var, e.g. label var temp "temperature" 
*/

/*
check for missing data 
misschk, gen(m)
tab mnumber 
keep if mnumber==0
*/

/***
\end{verbatim}

\section{Descriptive Statistics}

\begin{verbatim}
***/

* can generate clean tables

/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\output"
/**/ quietly eststo sumstats: quietly estpost summarize

/**/ quietly esttab sumstats using sumstats, ///
	cells("count mean sd min max") ///
	title("Summary Statistics") tex  replace
* note: do not use 'fragment' with esttab; doing so removes centering and 
* tabular syntax

* go back to main dir
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata"	

/***
\end{verbatim}

Here we import the table of summary statistics.\\

\input{./output/sumstats} 

Now lets generate and add a figure that visualizing one of these variables.\\

\begin{verbatim}
***/

* graphs
/**/ quietly hist medals, name(hist, replace) 

* export graph 1: if are away from main directory, can change dir and export;
* when in doubt, and if moving across different computers, this is best option
* to use:
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\figures"
/**/ quietly graph export graph1.png, width(3900) height(3900) replace

/* 
alternative: if are in main directory, can export to 'figures' subfolder:
graph export ./figures/graph1.png, width(3900) height(3900) replace
*/

* go back to main dir
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata"

/*
Now, in next LaTeX chunk, we import the figure with caption identifying it with a label which we 
will reference later in text.  
Note: we first set file path to ``figures'' subfolder in working directory.
*/

/***
\end{verbatim}

\graphicspath{{./figures/}}
% comment: note the double braces above in reference to graphics path

	\begin{figure}[h]
	\centering
	\includegraphics[width=4in,height=4in,angle=0]{graph1.png} 
	\caption{This graph shows the histogram of the price variable}
	\label{fig:graph1}
	\end{figure}
		
	We can write some text and reference the figure by noting that 
	Figure \ref{fig:graph1} shows a histogram of our data. \\
	\textbf{NOTE:}  you may need to compile your document twice in order for 
	the figure reference to be correct. \LaTeX compiles in layers, so if 	
	you do not see a recent change reflected in your compiled document, try 
	compiling again.
	
	\section{Regression}
	Let's end this template with a regression analysis.

	\begin{verbatim}
***/

/**/ quietly eststo m1: regress medals athletes gdp
/**/ quietly eststo m2: regress medals athletes gdp temp
/**/ quietly coefplot m1 m2, drop(_cons) xline(0)

/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\figures"
/**/ quietly graph export graph2.png, width(3900) height(3900) replace

* table export option 1, using outreg and if in main directory:
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\output"

/**/ quietly outreg using modelsoutreg, se summstat(r2\r2_a\rmse\N) ///
	summtitle("R-squared"\"Adjusted R2"\"RMSE"\"N") tex fragment replace

* note: outreg works with estimates currently in memory
* quietly option keeps table from printing as output
* a little more complicated to merge results from 2 or more models

* Prefer esttab without 'fragment' option; cleaner merge of 2+ models
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata\output"
/**/ quietly esttab m1 m2 using modelsesttab, se tex replace

* go back to main dir
/**/ quietly cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata"	 

/***
	\end{verbatim}
		
		Regression was saved as a clean table in \LaTeX file to folder 
		``output'', and we can now embed that clean, formatted table 
		directly into the document we are creating.\\
		
		This is table with \textit{outreg} command.
		
		\newcommand*{\PathOut}{./output}
		\input{./output/modelsoutreg} 		
		
		This is table with \textit{esttab} command.\\
		
		\begin{center}
		\input{./output/modelsesttab}
		\end{center}
		
		And we can also generate a graph that reports a visualization of the coefficients from 
		the regression analysis. Graphs like this can be an extremely useful 
		and more intuitive way of communicating your results.
		
		\begin{figure}[h]
		\centering
		\includegraphics[width=4in,height=4in,angle=0]{graph2.png} 
		\caption{This graph shows the coefficients for both regressions.}
		\label{fig:graph2}
		\end{figure}
		
		Then we can write some text and reference the figure by noting that 
		Figure \ref{fig:graph2} reports the coefficients. \\
		\textbf{NOTE:}  Again, you may need to compile your document twice in order for 
		the figure reference to be correct. \LaTeX compiles in layers, so if 	
		you do not see a recent change reflected in your compiled document, try 
		compiling again.
	
		
		
		\section{Conclusion}
		Finally, we would write our conclusion here. 

\end{document}
***/
	
/* ------------------------
close log file, return to home directory, and close out
---------------------------
*/
* option 1 (if using macros):					
quietly log close

* option 2: 
* log close

* switch back to home directory to compile files
cd "C:\Users\mi122167\Dropbox\SUNYAlbany\MethodsPOS517\Workflow\TPoL2017\demoStata"

* close all graphs and drop all macros
graph drop _all
macro drop _all	

/*
-----------------------------
export final tex document
-----------------------------
*/

/* Exporting in several formats */
*markdoc example1, replace 		/* exporting a markdown file */
*markdoc example1, replace export(html) 
*markdoc example1, replace export(odt) 
*markdoc example1, replace export(txt) 
*markdoc example1, replace export(epub) 
*markdoc mytemplatelatex, replace author() affiliation() export(docx) 
/* could add date option (no parentheses) */
*markdoc mytemplatelatex, replace author() affiliation() export(pdf)

* markdoc mytemplatelatex, replace author() affiliation() export(docx) markup()
* markdoc mytemplatelatex, replace author() affiliation() export(html) markup()
markdoc mytemplatelatexnomacros, replace author() affiliation() export(tex) markup()

/*
can also produce pdf slides:
markdoc example1, replace author(Matthew C. Ingram) affiliation(University at Albany, SUNY) date export(slide)
NOTE: this will replace any existing pdf file with same name, so be cautious
*/

* end
